@@ -12,29 +12,38 @@ header = {
     'User-Agent': 'Mozilla/5.0 (Windows NT 6.1; WOW64; rv:23.0) Gecko/20100101 Firefox/23.0'}
 
 
+def progress(done,size,total):
+    pre =100.0 * done * size / total
+    down = done * size
+    print2.print2.message('%0.2f%% @ %0.2fKB/%0.2fKB\r'%(pre,down/1024,total/1024))
+    if pre > 100:
+        print2.print2.message('\r')
+
+
+
 def get(url):
     try:
         req = request.Request(url, headers=header)
         data = request.urlopen(req).read().decode('utf-8')
         return data
+    except KeyboardInterrupt:
+        sys.exit()
     except:
         return 1
 
 
 def getJson(url):
-    try:
-        return json.loads(get(url))
-    except:
+    re = get(url)
+    if re == 1:
         return 1
+    return json.loads(re)
 
 def downloadB(url, path):
     try:
-        req = request.Request(url, headers=header)
-        data = request.urlopen(req).read()
-        with open(path, 'wb') as f:
-            f.write(data)
-            f.close()
+        request.urlretrieve(url, path, progress)
         return 0
+    except KeyboardInterrupt:
+        sys.exit()
     except:
         return 1
 
@@ -49,15 +58,17 @@ def uploadB(url, path):
         req = request.Request(url, data, headers=header2)
         data2 = request.urlopen(req).read().decode('utf-8')
         return data2
+    except KeyboardInterrupt:
+        sys.exit()
     except:
         return 1
 
 
 def uploadBJSON(url, path):
-    try:
-        return json.loads(uploadB(url, path))
-    except:
-        return 1
+    re = uploadB(url,path)
+    if re == 1:
+        return re
+    return json.loads(re)
 
 def post(url, data):
     try:
@@ -65,12 +76,14 @@ def post(url, data):
         req = request.Request(url, data3, headers=header)
         data2 = request.urlopen(req).read().decode('utf-8')
         return data2
+    except KeyboardInterrupt:
+        sys.exit()
     except:
         return 1
 
 
 def postJSON(url, data):
-    try:
-        return json.loads(post(url, data))
-    except:
-        return 1
\ No newline at end of file
+    re = post(url, data)
+    if re == 1:
+        return 1
+    return json.loads(post(url, data))
